==> ejc-ztpcdc-impl-3.0.0-20230608.013305-63-sources.jar: com/ejianc/business/dc/bean/DcDrawInfoEntity.java <==
package com.ejianc.business.dc.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.util.Date;

/**
 * 图纸信息
 *
 * @author generator
 */
@TableName("dc_draw_info")
public class DcDrawInfoEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value = "draw_code")
    private String drawCode; // 图纸编号
    @TableField(value = "draw_name")
    private String drawName; // 图纸名称
    @TableField(value = "draw_vsn")
    private String drawVsn; // 图纸版本
    @TableField(value = "drwgrp_code")
    private String drwgrpCode; // 卷册编号
    @TableField(value = "drwgrp_vsn")
    private String drwgrpVsn; // 卷册版本
    @TableField(value = "draw_type")
    private Long drawType; // 图纸类型
    @TableField(value = "transfer_code")
    private String transferCode; // 传递单号
    @TableField(value = "draw_arrive_date")
    private Date drawArriveDate; // 到图日期
    @TableField(value = "issue_sts")
    private String issueSts; // 签发状态
    @TableField(value = "draw_attachment")
    private String drawAttachment; // 图纸附件
    @TableField(value = "create_dept_id")
    private Long createDeptId; // 创建部门id
    @TableField(value = "org_id")
    private Long orgId; // 所属组织id
    @TableField(value = "org_code")
    private String orgCode; // 组织编码
    @TableField(value = "org_name")
    private String orgName; // 组织名称
    @TableField(value = "parent_org_id")
    private Long parentOrgId; // 所属组织
    @TableField(value = "parent_org_code")
    private String parentOrgCode; // 所属组织编码
    @TableField(value = "parent_org_name")
    private String parentOrgName; // 所属组织名称
    @TableField(value = "drwgrp_id")
    private Long drwgrpId; // 卷册ID

    public Long getDrwgrpId() {
        return drwgrpId;
    }

    public void setDrwgrpId(Long drwgrpId) {
        this.drwgrpId = drwgrpId;
    }

    public String getDrawCode() {
        return drawCode;
    }

    public void setDrawCode(String drawCode) {
        this.drawCode = drawCode;
    }

    public String getDrawName() {
        return drawName;
    }

    public void setDrawName(String drawName) {
        this.drawName = drawName;
    }

    public String getDrawVsn() {
        return drawVsn;
    }

    public void setDrawVsn(String drawVsn) {
        this.drawVsn = drawVsn;
    }

    public String getDrwgrpCode() {
        return drwgrpCode;
    }

    public void setDrwgrpCode(String drwgrpCode) {
        this.drwgrpCode = drwgrpCode;
    }

    public String getDrwgrpVsn() {
        return drwgrpVsn;
    }

    public void setDrwgrpVsn(String drwgrpVsn) {
        this.drwgrpVsn = drwgrpVsn;
    }

    public Long getDrawType() {
        return drawType;
    }

    public void setDrawType(Long drawType) {
        this.drawType = drawType;
    }

    public String getTransferCode() {
        return transferCode;
    }

    public void setTransferCode(String transferCode) {
        this.transferCode = transferCode;
    }

    public Date getDrawArriveDate() {
        return drawArriveDate;
    }

    public void setDrawArriveDate(Date drawArriveDate) {
        this.drawArriveDate = drawArriveDate;
    }

    public String getIssueSts() {
        return issueSts;
    }

    public void setIssueSts(String issueSts) {
        this.issueSts = issueSts;
    }

    public String getDrawAttachment() {
        return drawAttachment;
    }

    public void setDrawAttachment(String drawAttachment) {
        this.drawAttachment = drawAttachment;
    }

    public Long getCreateDeptId() {
        return createDeptId;
    }

    public void setCreateDeptId(Long createDeptId) {
        this.createDeptId = createDeptId;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }

    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }

    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }

}

==> ejc-ztpcdc-impl-3.0.0-20230717.145650-123-sources.jar: com/ejianc/business/dc/bean/DcDrawInfoEntity.java <==
package com.ejianc.business.dc.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.util.Date;

/**
 * 图纸信息
 *
 * @author generator
 */
@TableName("dc_draw_info")
public class DcDrawInfoEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value = "draw_code")
    private String drawCode; // 图纸编号
    @TableField(value = "draw_name")
    private String drawName; // 图纸名称
    @TableField(value = "draw_vsn")
    private String drawVsn; // 图纸版本
    @TableField(value = "drwgrp_code")
    private String drwgrpCode; // 卷册编号
    @TableField(value = "drwgrp_vsn")
    private String drwgrpVsn; // 卷册版本
    @TableField(value = "draw_type")
    private Long drawType; // 图纸类型
    @TableField(value = "transfer_code")
    private String transferCode; // 传递单号
    @TableField(value = "draw_arrive_date")
    private Date drawArriveDate; // 到图日期
    @TableField(value = "issue_sts")
    private String issueSts; // 签发状态
    @TableField(value = "draw_attachment")
    private String drawAttachment; // 图纸附件
    @TableField(value = "create_dept_id")
    private Long createDeptId; // 创建部门id
    @TableField(value = "org_id")
    private Long orgId; // 所属组织id
    @TableField(value = "org_code")
    private String orgCode; // 组织编码
    @TableField(value = "org_name")
    private String orgName; // 组织名称
    @TableField(value = "parent_org_id")
    private Long parentOrgId; // 所属组织
    @TableField(value = "parent_org_code")
    private String parentOrgCode; // 所属组织编码
    @TableField(value = "parent_org_name")
    private String parentOrgName; // 所属组织名称
    @TableField(value = "drwgrp_id")
    private Long drwgrpId; // 卷册ID
    @TableField(value = "project_id")
    private Long projectId; // 项目ID
    @TableField(value = "project_code")
    private String projectCode; // 项目编码
    @TableField(value = "project_name")
    private String projectName; // 项目名称

    public Long getDrwgrpId() {
        return drwgrpId;
    }

    public void setDrwgrpId(Long drwgrpId) {
        this.drwgrpId = drwgrpId;
    }

    public String getDrawCode() {
        return drawCode;
    }

    public void setDrawCode(String drawCode) {
        this.drawCode = drawCode;
    }

    public String getDrawName() {
        return drawName;
    }

    public void setDrawName(String drawName) {
        this.drawName = drawName;
    }

    public String getDrawVsn() {
        return drawVsn;
    }

    public void setDrawVsn(String drawVsn) {
        this.drawVsn = drawVsn;
    }

    public String getDrwgrpCode() {
        return drwgrpCode;
    }

    public void setDrwgrpCode(String drwgrpCode) {
        this.drwgrpCode = drwgrpCode;
    }

    public String getDrwgrpVsn() {
        return drwgrpVsn;
    }

    public void setDrwgrpVsn(String drwgrpVsn) {
        this.drwgrpVsn = drwgrpVsn;
    }

    public Long getDrawType() {
        return drawType;
    }

    public void setDrawType(Long drawType) {
        this.drawType = drawType;
    }

    public String getTransferCode() {
        return transferCode;
    }

    public void setTransferCode(String transferCode) {
        this.transferCode = transferCode;
    }

    public Date getDrawArriveDate() {
        return drawArriveDate;
    }

    public void setDrawArriveDate(Date drawArriveDate) {
        this.drawArriveDate = drawArriveDate;
    }

    public String getIssueSts() {
        return issueSts;
    }

    public void setIssueSts(String issueSts) {
        this.issueSts = issueSts;
    }

    public String getDrawAttachment() {
        return drawAttachment;
    }

    public void setDrawAttachment(String drawAttachment) {
        this.drawAttachment = drawAttachment;
    }

    public Long getCreateDeptId() {
        return createDeptId;
    }

    public void setCreateDeptId(Long createDeptId) {
        this.createDeptId = createDeptId;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }

    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }

    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

}
